@@ -39,10 +39,13 @@ from rteval.systopology import SysTopology
 
 class Hackbench(CommandLineLoad):
     def __init__(self, config, logger):
+        self.__cfg = config
         CommandLineLoad.__init__(self, "hackbench", config, logger)
 
-
     def _WorkloadSetup(self):
+        if self._donotrun:
+            return
+
         'calculate arguments based on input parameters'
         (mem, units) = self.memsize
         if units == 'KB':
@@ -51,13 +54,14 @@ class Hackbench(CommandLineLoad):
             mem = mem / 1024.0
         elif units == 'TB':
             mem = mem * 1024
+
         ratio = float(mem) / float(self.num_cpus)
-        if ratio >= 0.75:
-            mult = float(self._cfg.setdefault('jobspercore', 2))
-        else:
-            self._log(Log.INFO, "Low memory system (%f GB/core)! Not running" % ratio)
-            mult = 0
-            self._donotrun = True
+        if ratio < 0.75:
+            if self.__cfg.runlowmem:
+                self._log(Log.WARN, "Low memory system (%f GB/core)!" % ratio)
+            else:
+                self._log(Log.WARN, "Low memory system (%f GB/core)! Not running hackbench" % ratio)
+                self._donotrun = True
 
         sysTop = SysTopology()
         # get the number of nodes
@@ -101,7 +105,6 @@ class Hackbench(CommandLineLoad):
                      '-l', str(self._cfg.setdefault('loops', '1000')),
                      '-s', str(self._cfg.setdefault('datasize', '1000'))
                      ]
-        self.__err_sleep = 5.0
 
     def _WorkloadBuild(self):
         # Nothing to build, so we're basically ready
@@ -200,6 +203,9 @@ def ModuleParameters():
     return {"jobspercore": {"descr": "Number of working threads per CPU core",
                             "default": 5,
                             "metavar": "NUM"},
+            "runlowmem": {"descr": "Run hackbench on machines where low memory is detected",
+                            "default": False,
+                            "metavar": "True|False"}
             }
 
 
