@@ -18,8 +18,8 @@ CREATE DATABASE rteval ENCODING 'utf-8';
        rtiid  SERIAL,
        PRIMARY KEY(rtiid)
     );
-    GRANT SELECT ON rteval_info TO rtevaldb_parser;
-    INSERT INTO rteval_info (key, value) VALUES ('sql_schema_ver','1.1');
+    GRANT SELECT ON rteval_info TO rtevparser;
+    INSERT INTO rteval_info (key, value) VALUES ('sql_schema_ver','1.4');
 
 -- Enable plpgsql.  It is expected that this PL/pgSQL is available.
     CREATE LANGUAGE 'plpgsql';
@@ -106,6 +106,7 @@ CREATE DATABASE rteval ENCODING 'utf-8';
         kernel_ver      VARCHAR(32) NOT NULL,
         kernel_rt       BOOLEAN NOT NULL,
         arch            VARCHAR(12) NOT NULL,
+	distro		VARCHAR(64),
         run_start       TIMESTAMP WITH TIME ZONE NOT NULL,
         run_duration    INTEGER NOT NULL,
         load_avg        REAL NOT NULL,
@@ -126,8 +127,13 @@ CREATE DATABASE rteval ENCODING 'utf-8';
 -- /rteval/loads and /rteval/cyclictest/command_line
 --
     CREATE TABLE rtevalruns_details (
-        rterid        INTEGER REFERENCES rtevalruns(rterid) NOT NULL,
-        xmldata       xml NOT NULL,
+        rterid          INTEGER REFERENCES rtevalruns(rterid) NOT NULL,
+        annotation      TEXT,
+        num_cpu_cores   INTEGER,
+        num_cpu_sockets INTEGER,
+        cpu_core_spread INTEGER[],
+        numa_nodes      INTEGER,
+        xmldata         xml NOT NULL,
         PRIMARY KEY(rterid)
     );
     GRANT INSERT ON rtevalruns_details TO rtevparser;
